@@ -13,36 +13,31 @@
 
 /* forward declarations */
 static const char* get_extension(const char* path);
-static void build_index(djvu_document_t *djvu_document, miniexp_t expression, girara_tree_node_t* root);
+static void build_index(djvu_document_t* djvu_document, miniexp_t expression, girara_tree_node_t* root);
 static bool exp_to_str(miniexp_t expression, const char** string);
 static bool exp_to_int(miniexp_t expression, int* integer);
 static bool exp_to_rect(miniexp_t expression, zathura_rectangle_t* rect);
 
-ZATHURA_PLUGIN_REGISTER_WITH_FUNCTIONS(
-  "djvu",
-  VERSION_MAJOR, VERSION_MINOR, VERSION_REV,
-  ZATHURA_PLUGIN_FUNCTIONS({
-    .document_open           = djvu_document_open,
-    .document_free           = djvu_document_free,
-    .document_index_generate = djvu_document_index_generate,
-    .document_save_as        = djvu_document_save_as,
-    .page_init               = djvu_page_init,
-    .page_clear              = djvu_page_clear,
-    .page_search_text        = djvu_page_search_text,
-    .page_get_text           = djvu_page_get_text,
-    .page_links_get          = djvu_page_links_get,
-    .page_render             = djvu_page_render,
-    .page_render_cairo       = djvu_page_render_cairo
-  }),
-  ZATHURA_PLUGIN_MIMETYPES({
-    "image/vnd.djvu",
-    "image/vnd.djvu+multipage"
-  })
-)
+ZATHURA_PLUGIN_REGISTER_WITH_FUNCTIONS("djvu", VERSION_MAJOR, VERSION_MINOR, VERSION_REV,
+                                       ZATHURA_PLUGIN_FUNCTIONS({
+                                           .document_open           = djvu_document_open,
+                                           .document_free           = djvu_document_free,
+                                           .document_index_generate = djvu_document_index_generate,
+                                           .document_save_as        = djvu_document_save_as,
+                                           .page_init               = djvu_page_init,
+                                           .page_clear              = djvu_page_clear,
+                                           .page_search_text        = djvu_page_search_text,
+                                           .page_get_text           = djvu_page_get_text,
+                                           .page_get_selection      = djvu_page_get_selection,
+                                           .page_links_get          = djvu_page_links_get,
+                                           .page_render_cairo       = djvu_page_render_cairo,
+                                       }),
+                                       ZATHURA_PLUGIN_MIMETYPES({
+                                           "image/vnd.djvu",
+                                           "image/vnd.djvu+multipage",
+                                       }))
 
-zathura_error_t
-djvu_document_open(zathura_document_t* document)
-{
+zathura_error_t djvu_document_open(zathura_document_t* document) {
   zathura_error_t error = ZATHURA_ERROR_OK;
 
   if (document == NULL) {
@@ -57,9 +52,14 @@ djvu_document_open(zathura_document_t* document)
   }
 
   /* setup format */
-  static unsigned int masks[4] = {0x00FF0000, 0x0000FF00, 0x000000FF, 0xFF000000};
-  djvu_document->format = ddjvu_format_create(DDJVU_FORMAT_RGBMASK32, 4, masks);
+  unsigned int masks[4] = {
+      0x00FF0000,
+      0x0000FF00,
+      0x000000FF,
+      0xFF000000,
+  };
 
+  djvu_document->format = ddjvu_format_create(DDJVU_FORMAT_RGBMASK32, 4, masks);
   if (djvu_document->format == NULL) {
     error = ZATHURA_ERROR_UNKNOWN;
     goto error_free;
@@ -77,11 +77,7 @@ djvu_document_open(zathura_document_t* document)
 
   /* setup document */
   djvu_document->document =
-    ddjvu_document_create_by_filename(
-        djvu_document->context,
-        zathura_document_get_path(document),
-        FALSE
-    );
+      ddjvu_document_create_by_filename(djvu_document->context, zathura_document_get_path(document), FALSE);
 
   if (djvu_document->document == NULL) {
     error = ZATHURA_ERROR_UNKNOWN;
@@ -92,8 +88,7 @@ djvu_document_open(zathura_document_t* document)
   ddjvu_message_t* msg;
   ddjvu_message_wait(djvu_document->context);
 
-  while ((msg = ddjvu_message_peek(djvu_document->context)) &&
-         (msg->m_any.tag != DDJVU_DOCINFO)) {
+  while ((msg = ddjvu_message_peek(djvu_document->context)) && (msg->m_any.tag != DDJVU_DOCINFO)) {
     if (msg->m_any.tag == DDJVU_ERROR) {
       error = ZATHURA_ERROR_UNKNOWN;
       goto error_free;
@@ -110,8 +105,7 @@ djvu_document_open(zathura_document_t* document)
   }
 
   zathura_document_set_data(document, djvu_document);
-  zathura_document_set_number_of_pages(document,
-      ddjvu_document_get_pagenum(djvu_document->document));
+  zathura_document_set_number_of_pages(document, ddjvu_document_get_pagenum(djvu_document->document));
 
   return error;
 
@@ -132,9 +126,7 @@ error_out:
   return error;
 }
 
-zathura_error_t
-djvu_document_free(zathura_document_t* document, void* data)
-{
+zathura_error_t djvu_document_free(zathura_document_t* document, void* data) {
   djvu_document_t* djvu_document = data;
   if (document == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -150,9 +142,7 @@ djvu_document_free(zathura_document_t* document, void* data)
   return ZATHURA_ERROR_OK;
 }
 
-girara_tree_node_t*
-djvu_document_index_generate(zathura_document_t* document, void* data, zathura_error_t* error)
-{
+girara_tree_node_t* djvu_document_index_generate(zathura_document_t* document, void* data, zathura_error_t* error) {
   djvu_document_t* djvu_document = data;
   if (document == NULL || djvu_document == NULL) {
     if (error != NULL) {
@@ -162,8 +152,7 @@ djvu_document_index_generate(zathura_document_t* document, void* data, zathura_e
   }
 
   miniexp_t outline = miniexp_dummy;
-  while ((outline = ddjvu_document_get_outline(djvu_document->document)) ==
-      miniexp_dummy) {
+  while ((outline = ddjvu_document_get_outline(djvu_document->document)) == miniexp_dummy) {
     handle_messages(djvu_document, true);
   }
 
@@ -184,9 +173,7 @@ djvu_document_index_generate(zathura_document_t* document, void* data, zathura_e
   return root;
 }
 
-zathura_error_t
-djvu_document_save_as(zathura_document_t* document, void* data, const char* path)
-{
+zathura_error_t djvu_document_save_as(zathura_document_t* document, void* data, const char* path) {
   djvu_document_t* djvu_document = data;
   if (document == NULL || djvu_document == NULL || path == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -206,7 +193,7 @@ djvu_document_save_as(zathura_document_t* document, void* data, const char* path
     job = ddjvu_document_save(djvu_document->document, fp, 0, NULL);
   }
   while (ddjvu_job_done(job) != true) {
-      handle_messages(djvu_document, true);
+    handle_messages(djvu_document, true);
   }
 
   fclose(fp);
@@ -214,9 +201,7 @@ djvu_document_save_as(zathura_document_t* document, void* data, const char* path
   return ZATHURA_ERROR_OK;
 }
 
-zathura_error_t
-djvu_page_init(zathura_page_t* page)
-{
+zathura_error_t djvu_page_init(zathura_page_t* page) {
   if (page == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
@@ -228,8 +213,7 @@ djvu_page_init(zathura_page_t* page)
   ddjvu_pageinfo_t page_info;
 
   unsigned int index = zathura_page_get_index(page);
-  while ((status = ddjvu_document_get_pageinfo(djvu_document->document, index,
-          &page_info)) < DDJVU_JOB_OK) {
+  while ((status = ddjvu_document_get_pageinfo(djvu_document->document, index, &page_info)) < DDJVU_JOB_OK) {
     handle_messages(djvu_document, true);
   }
 
@@ -238,15 +222,13 @@ djvu_page_init(zathura_page_t* page)
     return ZATHURA_ERROR_UNKNOWN;
   }
 
-  zathura_page_set_width(page,  ZATHURA_DJVU_SCALE * page_info.width);
+  zathura_page_set_width(page, ZATHURA_DJVU_SCALE * page_info.width);
   zathura_page_set_height(page, ZATHURA_DJVU_SCALE * page_info.height);
 
   return ZATHURA_ERROR_OK;
 }
 
-zathura_error_t
-djvu_page_clear(zathura_page_t* page, void* UNUSED(data))
-{
+zathura_error_t djvu_page_clear(zathura_page_t* page, void* UNUSED(data)) {
   if (page == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
@@ -254,9 +236,8 @@ djvu_page_clear(zathura_page_t* page, void* UNUSED(data))
   return ZATHURA_ERROR_OK;
 }
 
-girara_list_t*
-djvu_page_search_text(zathura_page_t* page, void* UNUSED(data), const char* text, zathura_error_t* error)
-{
+girara_list_t* djvu_page_search_text(zathura_page_t* page, void* UNUSED(data), const char* text,
+                                     zathura_error_t* error) {
   if (page == NULL || text == NULL || strlen(text) == 0) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -300,10 +281,8 @@ error_ret:
   return NULL;
 }
 
-char*
-djvu_page_get_text(zathura_page_t* page, void* UNUSED(data), zathura_rectangle_t
-    rectangle, zathura_error_t* error)
-{
+char* djvu_page_get_text(zathura_page_t* page, void* UNUSED(data), zathura_rectangle_t rectangle,
+                         zathura_error_t* error) {
   if (page == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -323,37 +302,37 @@ djvu_page_get_text(zathura_page_t* page, void* UNUSED(data), zathura_rectangle_t
     goto error_ret;
   }
 
-  double tmp = 0;
+  double tmp         = 0;
   double page_height = zathura_page_get_height(page);
   double page_width  = zathura_page_get_width(page);
 
   switch (zathura_document_get_rotation(document)) {
-    case 90:
-      tmp = rectangle.x1;
-      rectangle.x1 = rectangle.y1;
-      rectangle.y1 = tmp;
-      tmp = rectangle.x2;
-      rectangle.x2 = rectangle.y2;
-      rectangle.y2 = tmp;
-      break;
-    case 180:
-      tmp = rectangle.x1;
-      rectangle.x1 = (page_width  - rectangle.x2);
-      rectangle.x2 = (page_width  - tmp);
-      break;
-    case 270:
-      tmp = rectangle.y2;
-      rectangle.y2 = (page_height - rectangle.x1);
-      rectangle.x1 = (page_width  - tmp);
-      tmp = rectangle.y1;
-      rectangle.y1 = (page_height - rectangle.x2);
-      rectangle.x2 = (page_width  - tmp);
-      break;
-    default:
-      tmp = rectangle.y1;
-      rectangle.y1 = (page_height - rectangle.y2);
-      rectangle.y2 = (page_height - tmp);
-      break;
+  case 90:
+    tmp          = rectangle.x1;
+    rectangle.x1 = rectangle.y1;
+    rectangle.y1 = tmp;
+    tmp          = rectangle.x2;
+    rectangle.x2 = rectangle.y2;
+    rectangle.y2 = tmp;
+    break;
+  case 180:
+    tmp          = rectangle.x1;
+    rectangle.x1 = (page_width - rectangle.x2);
+    rectangle.x2 = (page_width - tmp);
+    break;
+  case 270:
+    tmp          = rectangle.y2;
+    rectangle.y2 = (page_height - rectangle.x1);
+    rectangle.x1 = (page_width - tmp);
+    tmp          = rectangle.y1;
+    rectangle.y1 = (page_height - rectangle.x2);
+    rectangle.x2 = (page_width - tmp);
+    break;
+  default:
+    tmp          = rectangle.y1;
+    rectangle.y1 = (page_height - rectangle.y2);
+    rectangle.y2 = (page_height - tmp);
+    break;
   }
 
   /* adjust to scale */
@@ -377,9 +356,30 @@ error_ret:
   return NULL;
 }
 
-girara_list_t*
-djvu_page_links_get(zathura_page_t* page, void* UNUSED(data), zathura_error_t* error)
-{
+girara_list_t* djvu_page_get_selection(zathura_page_t* UNUSED(page), void* UNUSED(data), zathura_rectangle_t rectangle,
+                                       zathura_error_t* error) {
+  girara_list_t* list = girara_list_new2(g_free);
+  if (list == NULL) {
+    if (error != NULL) {
+      *error = ZATHURA_ERROR_OUT_OF_MEMORY;
+    }
+    goto error_free;
+  }
+
+  zathura_rectangle_t* rect = g_malloc0(sizeof(zathura_rectangle_t));
+  *rect                     = rectangle;
+  girara_list_append(list, rect);
+
+  return list;
+
+error_free:
+  if (list != NULL) {
+    girara_list_free(list);
+  }
+  return NULL;
+}
+
+girara_list_t* djvu_page_links_get(zathura_page_t* page, void* UNUSED(data), zathura_error_t* error) {
   if (page == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -392,7 +392,7 @@ djvu_page_links_get(zathura_page_t* page, void* UNUSED(data), zathura_error_t* e
     goto error_ret;
   }
 
-  girara_list_t* list = girara_list_new2((girara_free_function_t) zathura_link_free);
+  girara_list_t* list = girara_list_new2((girara_free_function_t)zathura_link_free);
   if (list == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_OUT_OF_MEMORY;
@@ -403,8 +403,8 @@ djvu_page_links_get(zathura_page_t* page, void* UNUSED(data), zathura_error_t* e
   djvu_document_t* djvu_document = zathura_document_get_data(document);
 
   miniexp_t annotations = miniexp_nil;
-  while ((annotations = ddjvu_document_get_pageanno(djvu_document->document,
-          zathura_page_get_index(page))) == miniexp_dummy) {
+  while ((annotations = ddjvu_document_get_pageanno(djvu_document->document, zathura_page_get_index(page))) ==
+         miniexp_dummy) {
     handle_messages(djvu_document, true);
   }
 
@@ -439,32 +439,33 @@ djvu_page_links_get(zathura_page_t* page, void* UNUSED(data), zathura_error_t* e
     /* extract link area */
     inner = miniexp_cdr(inner);
 
-    zathura_rectangle_t rect = { 0, 0, 0, 0 };
+    zathura_rectangle_t rect = {0, 0, 0, 0};
     if (exp_to_rect(miniexp_car(inner), &rect) == false) {
       continue;
     }
 
     /* update rect */
     unsigned int page_height = zathura_page_get_height(page) / ZATHURA_DJVU_SCALE;
-    rect.x1 = rect.x1 * ZATHURA_DJVU_SCALE;
-    rect.x2 = rect.x2 * ZATHURA_DJVU_SCALE;
-    double tmp = rect.y1;
-    rect.y1 = (page_height - rect.y2) * ZATHURA_DJVU_SCALE;
-    rect.y2 = (page_height - tmp)     * ZATHURA_DJVU_SCALE;
+    rect.x1                  = rect.x1 * ZATHURA_DJVU_SCALE;
+    rect.x2                  = rect.x2 * ZATHURA_DJVU_SCALE;
+    double tmp               = rect.y1;
+    rect.y1                  = (page_height - rect.y2) * ZATHURA_DJVU_SCALE;
+    rect.y2                  = (page_height - tmp) * ZATHURA_DJVU_SCALE;
 
     /* create zathura link */
-    zathura_link_type_t type = ZATHURA_LINK_INVALID;
-    zathura_link_target_t target = { ZATHURA_LINK_DESTINATION_UNKNOWN, NULL, 0, -1, -1, -1, -1, 0 };;
+    zathura_link_type_t type     = ZATHURA_LINK_INVALID;
+    zathura_link_target_t target = {ZATHURA_LINK_DESTINATION_UNKNOWN, NULL, 0, -1, -1, -1, -1, 0};
+    ;
 
     /* goto page */
     if (target_string[0] == '#' && target_string[1] == 'p') {
-      type = ZATHURA_LINK_GOTO_DEST;
+      type               = ZATHURA_LINK_GOTO_DEST;
       target.page_number = atoi(target_string + 2) - 1;
-    /* url or other? */
+      /* url or other? */
     } else if (strstr(target_string, "//") != NULL) {
-      type = ZATHURA_LINK_URI;
-      target.value = (char*) target_string;
-    /* TODO: Parse all different links */
+      type         = ZATHURA_LINK_URI;
+      target.value = (char*)target_string;
+      /* TODO: Parse all different links */
     } else {
       continue;
     }
@@ -488,10 +489,8 @@ error_ret:
   return NULL;
 }
 
-zathura_error_t
-djvu_page_render_cairo(zathura_page_t* page, void* UNUSED(data), cairo_t* cairo,
-    bool GIRARA_UNUSED(printing))
-{
+zathura_error_t djvu_page_render_cairo(zathura_page_t* page, void* UNUSED(data), cairo_t* cairo,
+                                       bool GIRARA_UNUSED(printing)) {
   if (page == NULL || cairo == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
@@ -515,20 +514,19 @@ djvu_page_render_cairo(zathura_page_t* page, void* UNUSED(data), cairo_t* cairo,
 
   cairo_surface_t* surface = cairo_get_target(cairo);
 
-  if (surface == NULL ||
-      cairo_surface_status(surface) != CAIRO_STATUS_SUCCESS ||
+  if (surface == NULL || cairo_surface_status(surface) != CAIRO_STATUS_SUCCESS ||
       cairo_surface_get_type(surface) != CAIRO_SURFACE_TYPE_IMAGE) {
     ddjvu_page_release(djvu_page);
     return ZATHURA_ERROR_UNKNOWN;
   }
 
   unsigned int page_width  = cairo_image_surface_get_width(surface);
-  unsigned int page_height = cairo_image_surface_get_height(surface);;
+  unsigned int page_height = cairo_image_surface_get_height(surface);
 
-  ddjvu_rect_t rrect = { 0, 0, page_width, page_height };
-  ddjvu_rect_t prect = { 0, 0, page_width, page_height };
+  ddjvu_rect_t rrect = {0, 0, page_width, page_height};
+  ddjvu_rect_t prect = {0, 0, page_width, page_height};
 
-  char* surface_data = (char*) cairo_image_surface_get_data(surface);
+  char* surface_data = (char*)cairo_image_surface_get_data(surface);
 
   if (surface_data == NULL) {
     ddjvu_page_release(djvu_page);
@@ -536,91 +534,15 @@ djvu_page_render_cairo(zathura_page_t* page, void* UNUSED(data), cairo_t* cairo,
   }
 
   /* render page */
-  ddjvu_page_render(djvu_page, DDJVU_RENDER_COLOR, &prect, &rrect,
-      djvu_document->format, cairo_image_surface_get_stride(surface), surface_data);
+  ddjvu_page_render(djvu_page, DDJVU_RENDER_COLOR, &prect, &rrect, djvu_document->format,
+                    cairo_image_surface_get_stride(surface), surface_data);
 
   ddjvu_page_release(djvu_page);
 
   return ZATHURA_ERROR_OK;
 }
 
-zathura_image_buffer_t*
-djvu_page_render(zathura_page_t* page, void* UNUSED(data), zathura_error_t* error)
-{
-  if (page == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
-    }
-    return NULL;
-  }
- 
-  zathura_document_t* document = zathura_page_get_document(page);
-  if (document == NULL) {
-    return NULL;
-  }
-
-  /* calculate sizes */
-  unsigned int page_width  = zathura_document_get_scale(document) * zathura_page_get_width(page);
-  unsigned int page_height = zathura_document_get_scale(document) * zathura_page_get_height(page);
-
-  if (page_width == 0 || page_height == 0) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_UNKNOWN;
-    }
-    goto error_out;
-  }
-
-  /* init ddjvu render data */
-  djvu_document_t* djvu_document = zathura_document_get_data(document);
-  ddjvu_page_t* djvu_page        = ddjvu_page_create_by_pageno(
-      djvu_document->document, zathura_page_get_index(page));
-
-  if (djvu_page == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_UNKNOWN;
-    }
-    goto error_out;
-  }
-
-  while (!ddjvu_page_decoding_done(djvu_page)) {
-    handle_messages(djvu_document, true);
-  }
-
-  ddjvu_rect_t rrect = { 0, 0, page_width, page_height };
-  ddjvu_rect_t prect = { 0, 0, page_width, page_height };
-
-  zathura_image_buffer_t* image_buffer =
-    zathura_image_buffer_create(page_width, page_height);
-
-  if (image_buffer == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_OUT_OF_MEMORY;
-    }
-    goto error_free;
-  }
-
-  /* set rotation */
-  ddjvu_page_set_rotation(djvu_page, DDJVU_ROTATE_0);
-
-  /* render page */
-  ddjvu_page_render(djvu_page, DDJVU_RENDER_COLOR, &prect, &rrect,
-      djvu_document->format, 3 * page_width, (char*) image_buffer->data);
-
-  return image_buffer;
-
-error_free:
-
-    ddjvu_page_release(djvu_page);
-    zathura_image_buffer_free(image_buffer);
-
-error_out:
-
-  return NULL;
-}
-
-static const char*
-get_extension(const char* path)
-{
+static const char* get_extension(const char* path) {
   if (path == NULL) {
     return NULL;
   }
@@ -641,9 +563,7 @@ get_extension(const char* path)
   return path + i + 1;
 }
 
-void
-handle_messages(djvu_document_t* document, bool wait)
-{
+void handle_messages(djvu_document_t* document, bool wait) {
   if (document == NULL || document->context == NULL) {
     return;
   }
@@ -660,24 +580,19 @@ handle_messages(djvu_document_t* document, bool wait)
   }
 }
 
-static void
-build_index(djvu_document_t *djvu_document, miniexp_t expression, girara_tree_node_t* root)
-{
+static void build_index(djvu_document_t* djvu_document, miniexp_t expression, girara_tree_node_t* root) {
   if (expression == miniexp_nil || root == NULL) {
     return;
   }
 
-  int fileno = ddjvu_document_get_filenum(djvu_document->document);
+  int fileno  = ddjvu_document_get_filenum(djvu_document->document);
   int curfile = 0;
 
   while (miniexp_consp(expression) != 0) {
     miniexp_t inner = miniexp_car(expression);
 
-    if (miniexp_consp(inner)
-        && miniexp_consp(miniexp_cdr(inner))
-        && miniexp_stringp(miniexp_car(inner))
-        && miniexp_stringp(miniexp_car(inner))
-       ) {
+    if (miniexp_consp(inner) && miniexp_consp(miniexp_cdr(inner)) && miniexp_stringp(miniexp_car(inner)) &&
+        miniexp_stringp(miniexp_car(inner))) {
       const char* name = miniexp_to_str(miniexp_car(inner));
       const char* link = miniexp_to_str(miniexp_cadr(inner));
 
@@ -687,13 +602,13 @@ build_index(djvu_document_t *djvu_document, miniexp_t expression, girara_tree_no
         continue;
       }
 
-      zathura_link_type_t type = ZATHURA_LINK_GOTO_DEST;
-      zathura_rectangle_t rect = { 0 };
-      zathura_link_target_t target = { 0 };
-      target.destination_type = ZATHURA_LINK_DESTINATION_XYZ;
+      zathura_link_type_t type     = ZATHURA_LINK_GOTO_DEST;
+      zathura_rectangle_t rect     = {0};
+      zathura_link_target_t target = {0};
+      target.destination_type      = ZATHURA_LINK_DESTINATION_XYZ;
 
       /* Check if link+1 contains a number */
-      bool number = true;
+      bool number          = true;
       const size_t linklen = strlen(link);
       for (unsigned int k = 1; k < linklen; k++) {
         if (!isdigit(link[k])) {
@@ -709,17 +624,17 @@ build_index(djvu_document_t *djvu_document, miniexp_t expression, girara_tree_no
         /* otherwise assume it is an id for a page */
         ddjvu_fileinfo_t info;
         int f, i;
-        for (i=0; i < fileno; i++) {
+        for (i = 0; i < fileno; i++) {
           f = (curfile + i) % fileno;
           ddjvu_document_get_fileinfo(djvu_document->document, f, &info);
-          if (info.id != NULL && !strcmp(link+1, info.id)) {
+          if (info.id != NULL && !strcmp(link + 1, info.id)) {
             break;
           }
         }
 
         /* got a page */
         if (i < fileno && info.pageno >= 0) {
-          curfile = (f+1) % fileno;
+          curfile            = (f + 1) % fileno;
           target.page_number = info.pageno;
         } else {
           /* give up */
@@ -749,9 +664,7 @@ build_index(djvu_document_t *djvu_document, miniexp_t expression, girara_tree_no
   }
 }
 
-static bool
-exp_to_str(miniexp_t expression, const char** string)
-{
+static bool exp_to_str(miniexp_t expression, const char** string) {
   if (string == NULL) {
     return false;
   }
@@ -764,9 +677,7 @@ exp_to_str(miniexp_t expression, const char** string)
   return false;
 }
 
-static bool
-exp_to_int(miniexp_t expression, int* integer)
-{
+static bool exp_to_int(miniexp_t expression, int* integer) {
   if (integer == NULL) {
     return false;
   }
@@ -779,12 +690,9 @@ exp_to_int(miniexp_t expression, int* integer)
   return false;
 }
 
-static bool
-exp_to_rect(miniexp_t expression, zathura_rectangle_t* rect)
-{
-  if ((miniexp_car(expression) == miniexp_symbol("rect")
-        || miniexp_car(expression) == miniexp_symbol("oval"))
-      && miniexp_length(expression) == 5) {
+static bool exp_to_rect(miniexp_t expression, zathura_rectangle_t* rect) {
+  if ((miniexp_car(expression) == miniexp_symbol("rect") || miniexp_car(expression) == miniexp_symbol("oval")) &&
+      miniexp_length(expression) == 5) {
     int min_x  = 0;
     int min_y  = 0;
     int width  = 0;
@@ -811,8 +719,7 @@ exp_to_rect(miniexp_t expression, zathura_rectangle_t* rect)
     rect->x2 = min_x + width;
     rect->y1 = min_y;
     rect->y2 = min_y + height;
-  } else if (miniexp_car(expression) == miniexp_symbol("poly")
-      && miniexp_length(expression) >= 5) {
+  } else if (miniexp_car(expression) == miniexp_symbol("poly") && miniexp_length(expression) >= 5) {
     int min_x = 0;
     int min_y = 0;
     int max_x = 0;
